| cps71 | R Documentation |
Canadian cross-section wage data consisting of a random sample taken from the 1971 Canadian Census Public Use Tapes for male individuals having common education (grade 13). There are 205 observations in total.
data("cps71")
A data frame with 2 columns, and 205 rows.
the first column, of type numeric
the second column, of type integer
Aman Ullah
Pagan, A. and A. Ullah (1999), Nonparametric Econometrics, Cambridge University Press.
data("cps71", package = "np")
if (interactive()) with(cps71, plot(age, logwage, xlab="Age", ylab="log(wage)"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.