gradients: Extract Gradients

View source: R/util.R

gradientsR Documentation

Extract Gradients

Description

gradients is a generic function which extracts gradients from objects.

Usage

gradients(x, ...)

## S3 method for class 'condensity'
gradients(x, errors = FALSE, ...)

## S3 method for class 'condistribution'
gradients(x, errors = FALSE, ...)

## S3 method for class 'npregression'
gradients(x, errors = FALSE, gradient.order = NULL, ...)

## S3 method for class 'qregression'
gradients(x, errors = FALSE, ...)

## S3 method for class 'singleindex'
gradients(x, errors = FALSE, ...)

Arguments

Object And Output Controls

Object to interrogate and whether gradient standard errors are requested.

x

an object for which the extraction of gradients is meaningful.

errors

a logical value specifying whether or not standard errors of gradients are desired. Defaults to FALSE.

Derivative Order Controls

Optional local-polynomial derivative order controls.

gradient.order

for npregression objects fitted with regtype="lp", optional derivative order request (scalar or one entry per continuous predictor). Orders exceeding the fitted polynomial degree (or greater than one, pending future C-level support) are returned as NA.

Additional Arguments

Further method-specific arguments.

...

other arguments.

Details

This function provides a generic interface for extraction of gradients from objects.

Value

Gradients extracted from the model object x.

Note

This method currently only supports objects from the np library.

Author(s)

Tristen Hayfield tristen.hayfield@gmail.com, Jeffrey S. Racine racinej@mcmaster.ca

References

See the references for the method being interrogated via gradients in the appropriate help file. For example, for the particulars of the gradients for nonparametric regression see the references in npreg

See Also

fitted, residuals, coef, and se, for related methods; np for supported objects.

Examples

x <- runif(10)
y <- x + rnorm(10, sd = 0.1)
gradients(npreg(y~x, gradients=TRUE))

np documentation built on May 3, 2026, 1:07 a.m.