| npseed | R Documentation |
npseed is a function which sets the random seed in the
np C backend, resetting the random number generator.
npseed(seed)
Seed value used to reset the package C backend random number generator.
seed |
a single finite numeric value that is representable as a non-negative integer after applying |
Documentation guide: see np.kernels for kernels, np.options for global options, and plot for plotting options.
npseed provides an interface for setting the random seed (and
resetting the random number generator) used
by np. The random number generator is used during the
bandwidth search procedure to set the search starting point, and in
subsequent searches when using multistarting, to avoid being trapped
in local minima if the objective function is not globally concave.
Calling npseed will only affect the numerical search if it is
performed by the C backend. The affected functions include:
npudensbw, npcdensbw,
npregbw, npplregbw, npqreg,
npcmstest (via npregbw),
npqcmstest (via npregbw),
npsigtest (via npregbw).
Invalid inputs such as missing values, non-finite values, non-scalars, and values that cannot be represented as integers are rejected with an explicit error.
None.
This method currently only supports objects from the np library.
Tristen Hayfield tristen.hayfield@gmail.com, Jeffrey S. Racine racinej@mcmaster.ca
Li, Q. and J.S. Racine (2007), Nonparametric Econometrics: Theory and Practice, Princeton University Press.
np.kernels, np.options, plot
set.seed
npseed(712)
x <- runif(10)
y <- x + rnorm(10, sd = 0.1)
bw <- npregbw(y~x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.